@@ -2,8 +2,7 @@
 
 __author__ = """Dominik Muhs"""
 __email__ = "dominik.muhs@consensys.net"
-__version__ = "1.6.2"
-
-from mythx_models.exceptions import MythXAPIError, MythXBaseException, ValidationError
+__version__ = "1.7.1"
 
+from mythx_models.exceptions import MythXAPIError
 from pythx.api.client import Client
